@@ -1,34 +1,28 @@
-import requests
-import re
-import os
-import json
-import time
-import logging
-import sys
-import json
-import os
-import ScratchEncoder
-import websocket
-logging.basicConfig(filename='s2py.log',level=logging.INFO)
+try:
+    import requests
+    import re
+    import os
+    import json
+    import time
+    import logging  
+    import sys  
+    import json
+    import os
+    import websocket
+except ModuleNotFoundError as e:
+    logging.info(e+'; Installing needed modules...')
+    os.chdir(os.getcwd())
+    os.system('pip install -r requirements.txt')
 try:
     ws = websocket.WebSocket()
 except TypeError:
     logging.info('Tye y when prompted to reinstall websocket-client')
     os.system('pip uninstall websocket-client')
     os.system('pip install websocket-client')
-encoder = ScratchEncoder.Encoder()
-try:
-    import ScratchEncoder
-    import websocket
-except ModuleNotFoundError as e:
-    logging.info(e+'; Installing needed modules...')
-    os.chdir(os.getcwd())
-    os.system('pip install -r requirements.txt')
-
-ws = websocket.WebSocket()
-encoder = ScratchEncoder.Encoder()
-
+logging.basicConfig(filename='s2py.log',level=logging.INFO)
 class Scratch2Py():
+    global chars
+    chars = "abcdefghijklmnopqrstuvwxyz0123456789+-. _"
     def __init__(self, username, password):
         global uname
         uname = username
@@ -81,10 +75,26 @@ class Scratch2Py():
             }
 
     def decode(self, text):
-        return encoder.decode(text)
-    
+        decoded = ""
+        y = 0
+        for i in range(0,len(text)//2):
+            x = chars[int(str(text[y])+str(text[int(y)+1]))-9]
+            decoded = str(decoded)+str(x)
+            y += 2
+        return decoded
+
     def encode(self, text):
-        return encoder.encode(text)
+        global chars
+        text = text.lower()
+        encoded = ""
+        length = int(len(text))
+        for i in range(0,length):
+            try:
+                x = int(chars.index(text[i])+int(9))
+                encoded = encoded + str(x)
+            except ValueError:
+                logging.error('Character not supported')
+        return encoded
     
     class project:
         def __init__(self, id):
@@ -436,6 +446,29 @@ class Scratch2Py():
                 'project_id': str(self.id)
             }) + '\n')
 
+        def __decode(self, text):
+            decoded = ""
+            y = 0
+            for i in range(0,len(text)//2):
+                x = chars[int(str(text[y])+str(text[int(y)+1]))-9]
+                decoded = str(decoded)+str(x)
+                y += 2
+            return decoded
+
+        def __encode(self, text):
+            global chars
+            text = text.lower()
+            encoded = ""
+            length = int(len(text))
+            for i in range(0,length):
+                try:
+                    x = int(chars.index(text[i])+int(9))
+                    encoded = encoded + str(x)
+                except ValueError:
+                    logging.error('Character not supported')
+            return encoded
+    
+        
         def __setCloudVar(self, variable, value):
             try:
                 ws.send(json.dumps({
@@ -485,13 +518,13 @@ class Scratch2Py():
             while True:
                 encodedMethod = self.__readCloudVar('Method')
                 if encodedMethod != None:
-                    Method = encoder.decode(encodedMethod)
+                    Method = self.decode(encodedMethod)
                 if Method == "set":
                     encodedSend = self.__readCloudVar('Send')
-                    Send = str(encoder.decode(encodedSend))
+                    Send = str(self.__decode(encodedSend))
                     encodedVal = self.__readCloudVar('Data')
-                    Val = str(encoder.decode(encodedVal))
-                    intVal = encoder.decode(encodedVal)
+                    Val = str(self.__decode(encodedVal))
+                    intVal = self.__decode(encodedVal)
                     c = 0
                     for i in Send:
                         if str(i) in "1234567890":
@@ -501,7 +534,7 @@ class Scratch2Py():
                             if int(Send) == int(len(data))+1:
                                 data.append(intVal)
                                 logging.info('Data added.')
-                                tosend = encoder.encode('Data added.')
+                                tosend = self.__encode('Data added.')
                                 self.__setCloudVar('Return',tosend)
                                 self.__setCloudVar('Method','')
                             else:
@@ -509,37 +542,37 @@ class Scratch2Py():
                                     data.append('none')
                                 data.append(intVal)
                                 logging.info('Data added.')
-                                tosend = encoder.encode('Data added.')
+                                tosend = self.__encode('Data added.')
                                 self.__setCloudVar('Return',tosend)
                                 self.__setCloudVar('Method','')
                         else:
                             data.pop(int(Send)-1)
                             data.insert(int(Send), intVal)
                             logging.info('Data added.')
-                            tosend = encoder.encode('Data added.')
+                            tosend = self.__encode('Data added.')
                             self.__setCloudVar('Return',tosend)
                             self.__setCloudVar('Method','')
                     else:
-                        tosend = encoder.encode('Invalid input. Variable name must be int.')
+                        tosend = self.__encode('Invalid input. Variable name must be int.')
                         self.__setCloudVar('Return', tosend)
                 if Method == "get":
                     encodedSend = self.__readCloudVar('Send')
-                    Send = encoder.decode(encodedSend)
+                    Send = self.__decode(encodedSend)
                     c = 0
                     for i in Send:
                         if str(i) in "1234567890":
                             c = int(c)+1
                     if c == len(Send) and int(Send) > 0 and int(Send) < int(len(data))+1:
-                        tosend = encoder.encode(data[int(Send)-1])
+                        tosend = self.__encode(data[int(Send)-1])
                         self.__setCloudVar('Return',tosend)
                         logging.info('Data sent.')
                         self.__setCloudVar('Method','')
                     else:
-                        tosend = encoder.encode('Invalid input.')
+                        tosend = self.__encode('Invalid input.')
                         self.__setCloudVar('Return', tosend)
                 if Method == "delete":
                     encodedSend = self.__readCloudVar('Send')
-                    Send = encoder.decode(encodedSend)
+                    Send = self.__decode(encodedSend)
                     c = 0
                     for i in Send:
                         if str(i) in "1234567890":
@@ -548,10 +581,10 @@ class Scratch2Py():
                         data.pop(int(Send)-1)
                         data.insert(int(Send)-1,'none')
                         logging.info('Variable deleted.')
-                        tosend = encoder.encode('Variable deleted.')
+                        tosend = self.__encode('Variable deleted.')
                         self.__setCloudVar('Return',tosend)
                     else:
-                        tosend = encoder.encode('Invalid input.')
+                        tosend = self.__encode('Invalid input.')
                         self.__setCloudVar('Return', tosend)                 
 
     class turbowarpConnect:
@@ -590,4 +623,4 @@ class Scratch2Py():
             for i in result:
                 if i['name'] == '☁ ' + variable:
                     return i['value']
-            return 'Variable not found.'
+            return 'Variable not found.'
\ No newline at end of file
